@@ -53,12 +53,17 @@ class SnowflakeS3Util:
     """S3 Utility class."""
 
     @staticmethod
-    def create_client(stage_info, use_accelerate_endpoint=False) -> Session.resource:
+    def create_client(
+        stage_info,
+        use_accelerate_endpoint=False,
+        use_s3_regional_url=False,
+    ) -> Session.resource:
         """Creates a client object with a stage credential.
 
         Args:
             stage_info: Information about the stage.
             use_accelerate_endpoint: Whether or not to use accelerated endpoint (Default value = False).
+            use_s3_regional_url: Whether or not to use regional url in aws deployments (Default value = False).
 
         Returns:
             The client to communicate with S3.
@@ -71,6 +76,11 @@ class SnowflakeS3Util:
             ("https://" + stage_info["endPoint"]) if stage_info["endPoint"] else None
         )
 
+        # If FIPS endpoint is in us-east-1 this will still work as we are testing for stage_info['endPoint'] which
+        # is populated only in the FIPS gov deployments.
+        if use_s3_regional_url and not stage_info["endPoint"]:
+            end_point = "https://" + "s3." + stage_info["region"] + ".amazonaws.com"
+
         config = Config(
             signature_version="s3v4",
             s3={
